@@ -11,13 +11,17 @@ except ImportError:
   raise SystemExit('[ERROR] Please make sure whisper is installed properly')
 
 # Ignore SIGPIPE
-signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+try:
+  signal.signal(signal.SIGPIPE, signal.SIG_DFL)
+except AttributeError:
+  #OS=windows
+  pass
 
 option_parser = optparse.OptionParser(usage='''%prog path [field]''')
 (options, args) = option_parser.parse_args()
 
 if len(args) < 1:
-  option_parser.print_usage()
+  option_parser.print_help()
   sys.exit(1)
 
 path = args[0]
@@ -28,27 +32,27 @@ else:
 
 try:
   info = whisper.info(path)
-except whisper.WhisperException, exc:
+except whisper.WhisperException as exc:
   raise SystemExit('[ERROR] %s' % str(exc))
 
 info['fileSize'] = os.stat(path).st_size
 
 if field:
   if field not in info:
-    print 'Unknown field "%s". Valid fields are %s' % (field, ','.join(info))
+    print('Unknown field "%s". Valid fields are %s' % (field, ','.join(info)))
     sys.exit(1)
 
-  print info[field]
+  print(info[field])
   sys.exit(0)
 
 
 archives = info.pop('archives')
 for key,value in info.items():
-  print '%s: %s' % (key,value)
+  print('%s: %s' % (key,value))
 print
 
 for i,archive in enumerate(archives):
-  print 'Archive %d' % i
+  print('Archive %d' % i)
   for key,value in archive.items():
-    print '%s: %s' % (key,value)
+    print('%s: %s' % (key,value))
   print
